#######
Credits
#######

Pants was originally written by John Sirois.

Major contributors in alphabetical order:

- Alec Thomas
- Benjy Weinberger
- Bill Farner
- Brian Wickman
- David Buchfuhrer
- John Sirois
- Mark McBride

If you are a contributor, please add your name to the list!
